==> flywheel_cli-11.2.0rc1-py3-none-any.whl: flywheel_cli/ingest/client/abstract.py <==
"""Abstract ingest client (CRUD) interface"""

import typing
import uuid
from abc import ABC, abstractmethod, abstractproperty

from .. import schemas as T
from .. import strategies
from ..config import IngestConfig


class Client(ABC):
    """Abstract ingest client interface"""

    def __init__(self, url: str):
        self.url = url
        self._ingest_id: typing.Optional[uuid.UUID] = None

    @classmethod
    def from_url(cls, url: str, ingest_id: typing.Optional[uuid.UUID] = None) -> "Client":
        """Return client instance, bind it to an ingest id if any provided"""
        client = cls(url)
        if ingest_id:
            client.bind(ingest_id)
        return client

    @property
    def ingest_id(self) -> uuid.UUID:
        """Raise when trying to use ingest bound method
        when the client is not bound to any ingest_id
        """
        if not self._ingest_id:
            raise TypeError("Accessing ingest_id on un-bound client")
        return self._ingest_id

    def bind(self, ingest_id: uuid.UUID) -> None:
        """Bind the client to an ingest id"""
        self._ingest_id = ingest_id

    # Non-ingest-bound methods

    @abstractmethod
    def create_ingest(
        self,
        config: IngestConfig,
        strategy_config: strategies.StrategyConfig,
        fw_auth: typing.Optional[T.FWAuth] = None
    ) -> T.IngestOutAPI:
        """Create a new ingest and bind the client to it"""

    @abstractmethod
    def list_ingests(self) -> typing.Iterable[T.IngestOutAPI]:
        """Get all ingests"""

    # Ingest-bound methods

    @abstractproperty
    def ingest(self) -> T.IngestOutAPI:
        """Get ingest operation the client is bound to"""

    @abstractmethod
    def load_subject_csv(self, subject_csv: typing.BinaryIO) -> None:
        """Load subject CSV file"""

    @abstractmethod
    def start(self) -> T.IngestOutAPI:
        """Start ingest scanning"""

    @abstractmethod
    def review(self, changes=None) -> T.IngestOutAPI:
        """Review (accept) ingest, add any changes and start importing"""

    @abstractmethod
    def abort(self) -> T.IngestOutAPI:
        """Abort ingest operation"""

    @abstractproperty
    def progress(self) -> T.Progress:
        """Get ingest scan task and item/file/byte counts by status"""

    @abstractproperty
    def summary(self) -> T.Summary:
        """Get ingest hierarchy node and file count by level and type"""

    @abstractproperty
    def report(self) -> T.Report:
        """Get ingest status, elapsed time per status and list of failed tasks"""

    @abstractproperty
    def tree(self) -> typing.Iterable[T.ContainerOut]:
        """Yield hierarchy nodes (containers)"""

    @abstractproperty
    def audit_logs(self) -> typing.Iterable[str]:
        """Yield audit log CSV lines"""

    @abstractproperty
    def deid_logs(self) -> typing.Iterable[str]:
        """Yield de-id log CSV lines"""

    @abstractproperty
    def subjects(self) -> typing.Iterable[str]:
        """Yield subject CSV lines"""

==> flywheel_cli-11.4.0rc1-py3-none-any.whl: flywheel_cli/ingest/client/abstract.py <==
"""Abstract ingest client (CRUD) interface"""

import typing
import uuid
from abc import ABC, abstractmethod, abstractproperty

from .. import schemas as T
from ..config import IngestConfig, StrategyConfig


class Client(ABC):
    """Abstract ingest client interface"""

    def __init__(self, url: str):
        self.url = url
        self._ingest_id: typing.Optional[uuid.UUID] = None

    @classmethod
    def from_url(cls, url: str, ingest_id: typing.Optional[uuid.UUID] = None) -> "Client":
        """Return client instance, bind it to an ingest id if any provided"""
        client = cls(url)
        if ingest_id:
            client.bind(ingest_id)
        return client

    @property
    def ingest_id(self) -> uuid.UUID:
        """Raise when trying to use ingest bound method
        when the client is not bound to any ingest_id
        """
        if not self._ingest_id:
            raise TypeError("Accessing ingest_id on un-bound client")
        return self._ingest_id

    def bind(self, ingest_id: uuid.UUID) -> None:
        """Bind the client to an ingest id"""
        self._ingest_id = ingest_id

    # Non-ingest-bound methods

    @abstractmethod
    def create_ingest(
        self,
        config: IngestConfig,
        strategy_config: StrategyConfig,
        fw_auth: typing.Optional[T.FWAuth] = None
    ) -> T.IngestOutAPI:
        """Create a new ingest and bind the client to it"""

    @abstractmethod
    def list_ingests(self) -> typing.Iterable[T.IngestOutAPI]:
        """Get all ingests"""

    # Ingest-bound methods

    @abstractproperty
    def ingest(self) -> T.IngestOutAPI:
        """Get ingest operation the client is bound to"""

    @abstractmethod
    def load_subject_csv(self, subject_csv: typing.BinaryIO) -> None:
        """Load subject CSV file"""

    @abstractmethod
    def start(self) -> T.IngestOutAPI:
        """Start ingest scanning"""

    @abstractmethod
    def review(self, changes=None) -> T.IngestOutAPI:
        """Review (accept) ingest, add any changes and start importing"""

    @abstractmethod
    def abort(self) -> T.IngestOutAPI:
        """Abort ingest operation"""

    @abstractproperty
    def progress(self) -> T.Progress:
        """Get ingest scan task and item/file/byte counts by status"""

    @abstractproperty
    def summary(self) -> T.Summary:
        """Get ingest hierarchy node and file count by level and type"""

    @abstractproperty
    def report(self) -> T.Report:
        """Get ingest status, elapsed time per status and list of failed tasks"""

    @abstractproperty
    def tree(self) -> typing.Iterable[T.ContainerOut]:
        """Yield hierarchy nodes (containers)"""

    @abstractproperty
    def audit_logs(self) -> typing.Iterable[str]:
        """Yield audit log CSV lines"""

    @abstractproperty
    def deid_logs(self) -> typing.Iterable[str]:
        """Yield de-id log CSV lines"""

    @abstractproperty
    def subjects(self) -> typing.Iterable[str]:
        """Yield subject CSV lines"""
